@@ -1,5 +1,5 @@
 /*
- * gpe-mini-browser v0.17
+ * gpe-mini-browser v0.18
  *
  * Basic web browser based on gtk-webcore 
  * 
@@ -436,7 +436,7 @@ show_bookmarks (GtkWidget * button, Webi * html)
 {
   GtkWidget *bookmarks_window, *bookbox, *scroll_window, *bookmark_list;
   GtkToolbar *booktool;
-  GtkToolItem *add, *del, *open_bookmark;
+  GtkToolItem *add, *del, *open_bookmark, *set_home;
   GtkTreeModel *model;
   GtkCellRenderer *cell;
   GtkTreeViewColumn *column;
@@ -446,7 +446,11 @@ show_bookmarks (GtkWidget * button, Webi * html)
   bookmarks_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_modal (GTK_WINDOW (bookmarks_window), TRUE);
   gtk_window_set_title (GTK_WINDOW (bookmarks_window), _("Bookmarks"));
+#ifdef HILDON
+  gtk_window_set_default_size (GTK_WINDOW (bookmarks_window), 420, 400);
+#else
   gtk_window_set_default_size (GTK_WINDOW (bookmarks_window), 240, 320);
+#endif /* HILDON */
   gtk_window_set_type_hint (GTK_WINDOW (bookmarks_window),
 			    GDK_WINDOW_TYPE_HINT_DIALOG);
   gtk_window_set_decorated (GTK_WINDOW (bookmarks_window), TRUE);
@@ -466,6 +470,10 @@ show_bookmarks (GtkWidget * button, Webi * html)
   gtk_tool_item_set_homogeneous (open_bookmark, FALSE);
   gtk_toolbar_insert (booktool, open_bookmark, -1);
 
+  set_home = gtk_tool_button_new_from_stock (GTK_STOCK_HOME);
+  gtk_tool_item_set_homogeneous (set_home, FALSE);
+  gtk_toolbar_insert (booktool, set_home, -1);
+
 #ifdef HILDON
   GtkToolItem *close_bookmark = gtk_tool_button_new_from_stock (GTK_STOCK_QUIT);
   gtk_tool_item_set_homogeneous (close_bookmark, FALSE);
@@ -516,6 +524,8 @@ show_bookmarks (GtkWidget * button, Webi * html)
 		    G_CALLBACK (destroy_window), bookmarks_window);
   g_signal_connect (GTK_OBJECT (bookmarks_window), "destroy",
 		    G_CALLBACK (stop_db), NULL);
+  g_signal_connect (GTK_OBJECT (set_home), "clicked",
+		    G_CALLBACK (set_as_homepage), &tree_info);
 #ifdef HILDON
   g_signal_connect (GTK_OBJECT (close_bookmark), "clicked",
 		    G_CALLBACK (destroy_window), bookmarks_window);
@@ -629,7 +639,11 @@ show_history (GtkWidget * button, Webi * html)
   gtk_window_set_modal (GTK_WINDOW (history_dialog), TRUE);
   gtk_container_set_border_width (GTK_CONTAINER (history_dialog),
 				  gpe_get_border ());
+#ifdef HILDON
+  gtk_window_set_default_size (GTK_WINDOW (history_dialog), 420, 400);
+#else
   gtk_window_set_default_size (GTK_WINDOW (history_dialog), 240, 320);
+#endif /* HILDON */
   gtk_window_set_type_hint (GTK_WINDOW (history_dialog),
 			    GDK_WINDOW_TYPE_HINT_DIALOG);
   gtk_window_set_decorated (GTK_WINDOW (history_dialog), TRUE);
@@ -674,6 +688,13 @@ show_history (GtkWidget * button, Webi * html)
   gtk_toolbar_insert (GTK_TOOLBAR (bar), open, -1);
   gtk_toolbar_insert (GTK_TOOLBAR (bar), clear, -1);
 
+#ifdef HILDON
+    GtkToolItem *close_bookmark = gtk_tool_button_new_from_stock (GTK_STOCK_QUIT);
+    gtk_tool_item_set_homogeneous (close_bookmark, FALSE);
+    gtk_toolbar_insert (bar, close_bookmark, -1);
+    g_signal_connect (GTK_OBJECT (close_bookmark), "clicked",
+                      G_CALLBACK (destroy_window), history_dialog);
+#endif
   g_signal_connect (GTK_OBJECT (open), "clicked",
 		    G_CALLBACK (open_bookmarks), &tree_info);
   g_signal_connect (GTK_OBJECT (open), "clicked",
